@@ -2,7 +2,8 @@ import inspect
 import typing
 from pathlib import Path
 from . import AnyOf, Deserializer, Enum, FunctionCall, Map, Serializer
-from .structures import ImmutableStructure, NoneField, Structure, Field
+from .structures import ImmutableStructure, NoneField, Structure, Field,get_typing_lib_info
+from .utility import type_is_generic
 
 INDENT = "    "
 
@@ -27,6 +28,7 @@ def _get_type_info(field, locals_attrs, additional_classes):
 
     if isinstance(field, Enum):
         if field._is_enum:
+            additional_classes.add(field._enum_class)
             return field._enum_class.__name__
 
     the_type = getattr(field, "get_type", field) if isinstance(field, Field) else field
@@ -37,10 +39,13 @@ def _get_type_info(field, locals_attrs, additional_classes):
         not the_type.__module__.startswith("typedpy")
         and the_type.__module__ != "builtins"
         and the_type not in locals_attrs
+        and not type_is_generic(the_type)
     ):
         additional_classes.add(field)
-    return f"{the_type.__name__}"
+    if type_is_generic(the_type):
+          return  _get_type_info(get_typing_lib_info(field),  locals_attrs, additional_classes)
 
+    return f"{the_type.__name__}"
 
 def _get_all_type_info(cls, locals_attrs, additional_classes) -> dict:
     type_by_name = {}
@@ -107,12 +112,16 @@ def _get_mapped_extra_imports(additional_imports) -> dict:
             if inspect.isclass(c) and issubclass(c, Structure):
                 module_name = c.__module__
             else:
-                module_name = c.get_type.__module__
+                module_name = ( c.get_type.__module__ if
+                               isinstance(c, Field) or (inspect.isclass(c) and issubclass(c, Field))
+                               else c.__module__
+                               )
             mapped[name] = module_name
         except Exception as e:
             print(f"Error: {e}")
     return mapped
 
+
     # [f"from {cls.__module__} import {cls.get_type}" for cls in additional_classes]
 
 
